==> eiffelstudio-18.11.10.2592.tar: F_code/C4/i1177.c <==
/*
 * Code for class I18N_BINARY_SEARCH_ARRAY_DICTIONARY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "i1177.h"
#include "eif_misc.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.make */
void F211_2698 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("make", 210, Current, 0, 1, 2846);
	RTGC;
	RTHOOK(1);
	F210_2682(Current, arg1);
	RTHOOK(2);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,850,0xFF01,395,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F851_6642(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.extend */
void F211_2699 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("extend", 210, Current, 0, 1, 2847);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
	F851_6669(RTCW(tr1), arg1, ti4_1);
	RTHOOK(2);
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_))++;
	RTHOOK(3);
	F211_2700(Current);
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.search_index_and_insert */
void F211_2700 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc8 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc9 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_NATURAL_32 tu4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(7);
	RTLR(0,Current);
	RTLR(1,loc4);
	RTLR(2,tr1);
	RTLR(3,loc5);
	RTLR(4,loc6);
	RTLR(5,loc7);
	RTLR(6,tr2);
	RTLIU(7);
	
	RTEAA("search_index_and_insert", 210, Current, 9, 0, 2848);
	RTGC;
	RTHOOK(1);
	loc9 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
	loc9 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc9 - ((EIF_INTEGER_32) 1L));
	RTHOOK(2);
	if ((EIF_BOOLEAN) (loc9 > ((EIF_INTEGER_32) 1L))) {
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		loc4 = F851_6648(RTCW(tr1), loc9);
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		loc5 = F851_6648(RTCW(tr1), ((EIF_INTEGER_32) 1L));
		RTHOOK(5);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		loc6 = F851_6648(RTCW(tr1), (EIF_INTEGER_32) (loc9 - ((EIF_INTEGER_32) 1L)));
		RTHOOK(6);
		tb1 = F396_4481(RTCW(loc4), loc5);
		if (tb1) {
			RTHOOK(7);
			loc8 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		} else {
			RTHOOK(8);
			tb1 = F395_4465(RTCW(loc4), loc6);
			if (tb1) {
				RTHOOK(9);
				loc8 = (EIF_INTEGER_32) loc9;
			} else {
				RTHOOK(10);
				loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
				RTHOOK(11);
				loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc9 - ((EIF_INTEGER_32) 2L));
				for (;;) {
					RTHOOK(12);
					if ((EIF_BOOLEAN) (loc1 > loc2)) break;
					RTHOOK(13);
					tu4_1 = (EIF_NATURAL_32) (EIF_INTEGER_32) (loc1 + loc2);
					tu4_1 = eif_bit_shift_right(tu4_1,((EIF_INTEGER_32) 1L));
					loc3 = (EIF_INTEGER_32) tu4_1;
					RTHOOK(14);
					tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
					loc7 = F851_6648(RTCW(tr1), loc3);
					RTHOOK(15);
					tb1 = F396_4481(RTCW(loc4), loc7);
					if (tb1) {
						RTHOOK(16);
						loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 1L));
					} else {
						RTHOOK(17);
						loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L));
					}
				}
				RTHOOK(18);
				loc8 = (EIF_INTEGER_32) loc1;
			}
		}
		RTHOOK(19);
		if ((EIF_BOOLEAN)(loc8 != loc9)) {
			RTHOOK(20);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			tr2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			F851_6672(RTCW(tr1), tr2, loc8, (EIF_INTEGER_32) (loc9 - ((EIF_INTEGER_32) 1L)), (EIF_INTEGER_32) (loc8 + ((EIF_INTEGER_32) 1L)));
			RTHOOK(21);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			F851_6667(RTCW(tr1), loc4, loc8);
		}
	}
	RTHOOK(22);
	RTLE;
	RTEE;
}

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.has_index */
EIF_INTEGER_32 F211_2701 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN loc5 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc7 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc9 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc10 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc11 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc12 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_NATURAL_32 tu4_1;
	EIF_BOOLEAN tb1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,loc6);
	RTLR(2,arg1);
	RTLR(3,loc12);
	RTLR(4,tr1);
	RTLR(5,loc4);
	RTLIU(6);
	
	RTEAA("has_index", 210, Current, 12, 1, 2849);
	RTGC;
	RTHOOK(1);
	loc7 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
	loc7 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc7 - ((EIF_INTEGER_32) 1L));
	RTHOOK(2);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(3);
	loc2 = (EIF_INTEGER_32) loc7;
	RTHOOK(4);
	loc6 = F1051_7968(RTCW(arg1));
	for (;;) {
		RTHOOK(8);
		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc1 > loc2) || loc5)) break;
		RTHOOK(9);
		tu4_1 = (EIF_NATURAL_32) (EIF_INTEGER_32) (loc1 + loc2);
		tu4_1 = eif_bit_shift_right(tu4_1,((EIF_INTEGER_32) 1L));
		loc3 = (EIF_INTEGER_32) tu4_1;
		RTHOOK(10);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr1 = F851_6648(RTCW(tr1), loc3);
		loc12 = tr1;
		if ((EIF_TRUE)) {
			RTHOOK(11);
			loc4 = F396_4475(loc12);
		} else {
			
			RTHOOK(13);
			tr1 = RTLNS(eif_new_type(1059, 0x01).id, 1059, _OBJSIZ_1_1_0_3_0_0_0_0_);
			F1051_7909(RTCW(tr1));
			loc4 = (EIF_REFERENCE) tr1;
		}
		RTHOOK(14);
		tb1 = F1058_8230(RTCW(loc6), loc4);
		if (tb1) {
			RTHOOK(15);
			loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 1L));
		} else {
			RTHOOK(16);
			tb1 = F395_4465(RTCW(loc6), loc4);
			if (tb1) {
				RTHOOK(17);
				loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L));
			} else {
				RTHOOK(18);
				loc5 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
				RTHOOK(19);
				Result = (EIF_INTEGER_32) loc3;
				RTHOOK(20);
				loc1++;
			}
		}
	}
	RTHOOK(21);
	if ((EIF_BOOLEAN)(loc5 == (EIF_BOOLEAN) 0)) {
		RTHOOK(22);
		RTHOOK(23);
		RTLE;
		RTEE;
		return (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
	}
	RTHOOK(24);
	RTLE;
	RTEE;
	return Result;
}

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.singular_in_context */
EIF_REFERENCE F211_2703 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(5);
	RTLR(0,arg1);
	RTLR(1,arg2);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTEAA("singular_in_context", 210, Current, 2, 2, 2851);
	RTGC;
	RTHOOK(1);
	tr1 = F206_2633(Current, arg1, arg2);
	loc1 = F211_2701(Current, tr1);
	RTHOOK(2);
	tb1 = '\0';
	if ((EIF_BOOLEAN)(loc1 != ((EIF_INTEGER_32) -1L))) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr1 = F851_6648(RTCW(tr1), loc1);
		loc2 = tr1;
		tb1 = (EIF_TRUE);
	}
	if (tb1) {
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(loc2 + _REFACS_2_);
		RTHOOK(4);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) tr1;
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) 0;
}

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.array */
EIF_REFERENCE F211_2706 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


void EIF_Minit177 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C4/i1177.c <==
/*
 * Code for class I18N_BINARY_SEARCH_ARRAY_DICTIONARY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "i1177.h"
#include "eif_misc.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.make */
void F211_2685 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("make", 210, Current, 0, 1, 2832);
	RTGC;
	RTHOOK(1);
	F210_2669(Current, arg1);
	RTHOOK(2);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,851,0xFF01,377,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F852_6655(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.extend */
void F211_2686 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("extend", 210, Current, 0, 1, 2833);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	F852_6682(RTCW(tr1), arg1, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_));
	RTHOOK(2);
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_))++;
	RTHOOK(3);
	F211_2687(Current);
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.search_index_and_insert */
void F211_2687 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc8 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc9 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_NATURAL_32 tu4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,loc4);
	RTLR(2,tr1);
	RTLR(3,loc5);
	RTLR(4,loc6);
	RTLR(5,loc7);
	RTLIU(6);
	
	RTEAA("search_index_and_insert", 210, Current, 9, 0, 2834);
	RTGC;
	RTHOOK(1);
	loc9 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
	loc9 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc9 - ((EIF_INTEGER_32) 1L));
	RTHOOK(2);
	if ((EIF_BOOLEAN) (loc9 > ((EIF_INTEGER_32) 1L))) {
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		loc4 = F852_6661(RTCW(tr1), loc9);
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		loc5 = F852_6661(RTCW(tr1), ((EIF_INTEGER_32) 1L));
		RTHOOK(5);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		loc6 = F852_6661(RTCW(tr1), (EIF_INTEGER_32) (loc9 - ((EIF_INTEGER_32) 1L)));
		RTHOOK(6);
		tb1 = F378_4230(RTCW(loc4), loc5);
		if (tb1) {
			RTHOOK(7);
			loc8 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		} else {
			RTHOOK(8);
			tb1 = F377_4214(RTCW(loc4), loc6);
			if (tb1) {
				RTHOOK(9);
				loc8 = (EIF_INTEGER_32) loc9;
			} else {
				RTHOOK(10);
				loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
				RTHOOK(11);
				loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc9 - ((EIF_INTEGER_32) 2L));
				for (;;) {
					RTHOOK(12);
					if ((EIF_BOOLEAN) (loc1 > loc2)) break;
					RTHOOK(13);
					tu4_1 = (EIF_NATURAL_32) (EIF_INTEGER_32) (loc1 + loc2);
					tu4_1 = eif_bit_shift_right(tu4_1,((EIF_INTEGER_32) 1L));
					loc3 = (EIF_INTEGER_32) tu4_1;
					RTHOOK(14);
					tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
					loc7 = F852_6661(RTCW(tr1), loc3);
					RTHOOK(15);
					tb1 = F378_4230(RTCW(loc4), loc7);
					if (tb1) {
						RTHOOK(16);
						loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 1L));
					} else {
						RTHOOK(17);
						loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L));
					}
				}
				RTHOOK(18);
				loc8 = (EIF_INTEGER_32) loc1;
			}
		}
		RTHOOK(19);
		if ((EIF_BOOLEAN)(loc8 != loc9)) {
			RTHOOK(20);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			F852_6685(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_1_), loc8, (EIF_INTEGER_32) (loc9 - ((EIF_INTEGER_32) 1L)), (EIF_INTEGER_32) (loc8 + ((EIF_INTEGER_32) 1L)));
			RTHOOK(21);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			F852_6680(RTCW(tr1), loc4, loc8);
		}
	}
	RTHOOK(22);
	RTLE;
	RTEE;
}

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.has_index */
EIF_INTEGER_32 F211_2688 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN loc5 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc7 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc9 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc10 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc11 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc12 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_NATURAL_32 tu4_1;
	EIF_BOOLEAN tb1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,loc6);
	RTLR(2,arg1);
	RTLR(3,loc12);
	RTLR(4,tr1);
	RTLR(5,loc4);
	RTLIU(6);
	
	RTEAA("has_index", 210, Current, 12, 1, 2835);
	RTGC;
	RTHOOK(1);
	loc7 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
	loc7 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc7 - ((EIF_INTEGER_32) 1L));
	RTHOOK(2);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(3);
	loc2 = (EIF_INTEGER_32) loc7;
	RTHOOK(4);
	loc6 = F1052_7991(RTCW(arg1));
	for (;;) {
		RTHOOK(8);
		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc1 > loc2) || loc5)) break;
		RTHOOK(9);
		tu4_1 = (EIF_NATURAL_32) (EIF_INTEGER_32) (loc1 + loc2);
		tu4_1 = eif_bit_shift_right(tu4_1,((EIF_INTEGER_32) 1L));
		loc3 = (EIF_INTEGER_32) tu4_1;
		RTHOOK(10);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr1 = F852_6661(RTCW(tr1), loc3);
		loc12 = tr1;
		if ((EIF_TRUE)) {
			RTHOOK(11);
			loc4 = F378_4224(loc12);
		} else {
			
			RTHOOK(13);
			loc4 = RTLNS(eif_new_type(1060, 0x01).id, 1060, _OBJSIZ_1_1_0_3_0_0_0_0_);
			F1052_7932(RTCW(loc4));
		}
		RTHOOK(14);
		tb1 = F1059_8253(RTCW(loc6), loc4);
		if (tb1) {
			RTHOOK(15);
			loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 1L));
		} else {
			RTHOOK(16);
			tb1 = F377_4214(RTCW(loc6), loc4);
			if (tb1) {
				RTHOOK(17);
				loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L));
			} else {
				RTHOOK(18);
				loc5 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
				RTHOOK(19);
				Result = (EIF_INTEGER_32) loc3;
				RTHOOK(20);
				loc1++;
			}
		}
	}
	RTHOOK(21);
	if ((EIF_BOOLEAN)(loc5 == (EIF_BOOLEAN) 0)) {
		RTHOOK(22);
		RTHOOK(23);
		RTLE;
		RTEE;
		return (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
	}
	RTHOOK(24);
	RTLE;
	RTEE;
	return Result;
}

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.singular_in_context */
EIF_REFERENCE F211_2690 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(5);
	RTLR(0,arg1);
	RTLR(1,arg2);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTEAA("singular_in_context", 210, Current, 2, 2, 2837);
	RTGC;
	RTHOOK(1);
	tr1 = F206_2620(Current, arg1, arg2);
	loc1 = F211_2688(Current, tr1);
	RTHOOK(2);
	tb1 = '\0';
	if ((EIF_BOOLEAN)(loc1 != ((EIF_INTEGER_32) -1L))) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr1 = F852_6661(RTCW(tr1), loc1);
		loc2 = tr1;
		tb1 = (EIF_TRUE);
	}
	if (tb1) {
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(loc2 + _REFACS_2_);
		RTHOOK(4);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) tr1;
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) 0;
}

void EIF_Minit177 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
